@@ -11,7 +11,7 @@ from types import FunctionType as Function
 from typing import Any, Callable, Dict, List, Type, TypeVar, Union, cast
 from reprlib import recursive_repr
 
-DataClass = Any  # type hint for variables that should be data class instances
+DataClass = TypeVar('DataClass')  # type hint representing a generic data class instance
 
 
 class Hint(type):
@@ -59,8 +59,8 @@ def factory(producer: Callable[[], Factory.Produces]) -> Factory.Produces:
 
 class DataClassMeta(type):
     """The metaclass that implements data class behaviour."""
-    DEFAULT_OPTIONS = dict(init=True, repr=True, eq=True, iter=False, frozen=False, order=False, unsafe_hash=False,
-                           kwargs=False, slots=False, hide_internals=True)
+    DEFAULT_OPTIONS = dict(init=True, repr=True, eq=True, order=False, unsafe_hash=False, frozen=False,
+                           hide_internals=True, iter=False, kwargs=False, slots=False)
 
     def __new__(mcs, name, bases, dict_, **kwargs):
         """Create a new data class."""
@@ -80,7 +80,7 @@ class DataClassMeta(type):
         # record all functions defined by the user up through the inheritance chain
         all_attrs = {a for b in bases for a in dir(b) if is_user_func(getattr(b, a, None))} | dict_.keys()
 
-        dataclass_bases = [vars(b) for b in bases if hasattr(b, '__dataclass__')]
+        dataclass_bases = [vars(b) for b in bases if isinstance(b, mcs)]
         for b in dataclass_bases + [dict_]:
             all_annotations.update(b.get('__annotations__', {}))
             all_defaults.update(b.get('__defaults__', {}))
@@ -107,7 +107,7 @@ class DataClassMeta(type):
             # not dict, otherwise Python will interpret them as read only
             for d in all_annotations.keys() & dict_.keys():
                 del dict_[d]
-            dict_['__slots__'] = tuple(all_annotations.keys() - all_slots)
+            dict_.setdefault('__slots__', tuple(all_annotations.keys() - all_slots))
         elif '__slots__' in dict_:
             # if the slots option gets removed, remove __slots__
             del dict_['__slots__']
@@ -144,7 +144,8 @@ class DataClassMeta(type):
 
         # determine a static expression for an instance's fields as a tuple, then evaluate this to create a property
         # allowing efficient representation for internal methods
-        tuple_expr = ', '.join((*(f'self.{f}' for f in fields(cls)), ''))  # '' ensures closing comma
+        internals = not cls.__dataclass__['hide_internals']
+        tuple_expr = ' '.join(f'self.{f},' for f in fields(cls, internals))
         cls.__tuple__ = property(eval(f'lambda self: ({tuple_expr})'))
 
 
