@@ -18,13 +18,13 @@ def dataclass(cls: Optional[type] = None, *, meta=DataClassMeta, **options) -> T
     :key init: Generate an __init__ method
     :key repr: Generate a __repr__ method
     :key eq: Generate an __eq__ method
-    :key iter: Generate an __iter__ method
-    :key frozen: Allow field reassignment after initialisation
-    :key kwargs: Append **kwargs to the list of initialiser parameters
-    :key slots: Generate __slots__
     :key order: Generate comparison methods other than __eq__
     :key unsafe_hash: Force generation of __hash__
-    :key hide_internals: Hide internal methods in __repr__
+    :key frozen: Allow field reassignment after initialisation
+    :key hide_internals: Hide internal methods in __repr__, __iter__ and comparison methods
+    :key iter: Generate an __iter__ method
+    :key kwargs: Append **kwargs to the list of initialiser parameters
+    :key slots: Generate __slots__
     :return: The newly created data class
     """
     assert issubclass(meta, DataClassMeta)
